pb

package
v0.0.0-...-177061b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 5, 2024 License: MIT Imports: 8 Imported by: 3

Documentation

Index

Constants

const (
	Monitoring_Service_SayHello_FullMethodName = "/monitoring.Monitoring_Service/SayHello"
)

Variables

var File_monitoring_proto protoreflect.FileDescriptor
var Monitoring_Service_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "monitoring.Monitoring_Service",
	HandlerType: (*Monitoring_ServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "SayHello",
			Handler:       _Monitoring_Service_SayHello_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "monitoring.proto",
}

Monitoring_Service_ServiceDesc is the grpc.ServiceDesc for Monitoring_Service service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterMonitoring_ServiceServer

func RegisterMonitoring_ServiceServer(s grpc.ServiceRegistrar, srv Monitoring_ServiceServer)

Types

type MonitoringRequest

type MonitoringRequest struct {
	StartMonitoring string `protobuf:"bytes,1,opt,name=start_monitoring,json=startMonitoring,proto3" json:"start_monitoring,omitempty"` //ex: "KRW-BTC"
	// contains filtered or unexported fields
}

func (*MonitoringRequest) Descriptor deprecated

func (*MonitoringRequest) Descriptor() ([]byte, []int)

Deprecated: Use MonitoringRequest.ProtoReflect.Descriptor instead.

func (*MonitoringRequest) GetStartMonitoring

func (x *MonitoringRequest) GetStartMonitoring() string

func (*MonitoringRequest) ProtoMessage

func (*MonitoringRequest) ProtoMessage()

func (*MonitoringRequest) ProtoReflect

func (x *MonitoringRequest) ProtoReflect() protoreflect.Message

func (*MonitoringRequest) Reset

func (x *MonitoringRequest) Reset()

func (*MonitoringRequest) String

func (x *MonitoringRequest) String() string

type MonitoringResponse

type MonitoringResponse struct {
	Market              string  `protobuf:"bytes,1,opt,name=market,proto3" json:"market,omitempty"`
	TradeDate           string  `protobuf:"bytes,2,opt,name=trade_date,json=tradeDate,proto3" json:"trade_date,omitempty"`
	TradeTime           string  `protobuf:"bytes,3,opt,name=trade_time,json=tradeTime,proto3" json:"trade_time,omitempty"`
	TradeDateKst        string  `protobuf:"bytes,4,opt,name=trade_date_kst,json=tradeDateKst,proto3" json:"trade_date_kst,omitempty"`
	TradeTimeKst        string  `protobuf:"bytes,5,opt,name=trade_time_kst,json=tradeTimeKst,proto3" json:"trade_time_kst,omitempty"`
	TradeTimestamp      int64   `protobuf:"varint,6,opt,name=trade_timestamp,json=tradeTimestamp,proto3" json:"trade_timestamp,omitempty"`
	OpeningPrice        int64   `protobuf:"varint,7,opt,name=opening_price,json=openingPrice,proto3" json:"opening_price,omitempty"`
	HighPrice           int64   `protobuf:"varint,8,opt,name=high_price,json=highPrice,proto3" json:"high_price,omitempty"`
	LowPrice            int64   `protobuf:"varint,9,opt,name=low_price,json=lowPrice,proto3" json:"low_price,omitempty"`
	TradePrice          int64   `protobuf:"varint,10,opt,name=trade_price,json=tradePrice,proto3" json:"trade_price,omitempty"`
	PrevClosingPrice    int64   `protobuf:"varint,11,opt,name=prev_closing_price,json=prevClosingPrice,proto3" json:"prev_closing_price,omitempty"`
	Change              string  `protobuf:"bytes,12,opt,name=change,proto3" json:"change,omitempty"` // "FALL" 또는 "RISE"
	ChangePrice         int64   `protobuf:"varint,13,opt,name=change_price,json=changePrice,proto3" json:"change_price,omitempty"`
	ChangeRate          float64 `protobuf:"fixed64,14,opt,name=change_rate,json=changeRate,proto3" json:"change_rate,omitempty"`
	SignedChangePrice   int64   `protobuf:"varint,15,opt,name=signed_change_price,json=signedChangePrice,proto3" json:"signed_change_price,omitempty"`
	SignedChangeRate    float64 `protobuf:"fixed64,16,opt,name=signed_change_rate,json=signedChangeRate,proto3" json:"signed_change_rate,omitempty"`
	TradeVolume         float64 `protobuf:"fixed64,17,opt,name=trade_volume,json=tradeVolume,proto3" json:"trade_volume,omitempty"`
	AccTradePrice       float64 `protobuf:"fixed64,18,opt,name=acc_trade_price,json=accTradePrice,proto3" json:"acc_trade_price,omitempty"`
	AccTradePrice_24H   float64 `protobuf:"fixed64,19,opt,name=acc_trade_price_24h,json=accTradePrice24h,proto3" json:"acc_trade_price_24h,omitempty"`
	AccTradeVolume      float64 `protobuf:"fixed64,20,opt,name=acc_trade_volume,json=accTradeVolume,proto3" json:"acc_trade_volume,omitempty"`
	AccTradeVolume_24H  float64 `protobuf:"fixed64,21,opt,name=acc_trade_volume_24h,json=accTradeVolume24h,proto3" json:"acc_trade_volume_24h,omitempty"`
	Highest_52WeekPrice int64   `protobuf:"varint,22,opt,name=highest_52_week_price,json=highest52WeekPrice,proto3" json:"highest_52_week_price,omitempty"`
	Highest_52WeekDate  string  `protobuf:"bytes,23,opt,name=highest_52_week_date,json=highest52WeekDate,proto3" json:"highest_52_week_date,omitempty"`
	Lowest_52WeekPrice  int64   `protobuf:"varint,24,opt,name=lowest_52_week_price,json=lowest52WeekPrice,proto3" json:"lowest_52_week_price,omitempty"`
	Lowest_52WeekDate   string  `protobuf:"bytes,25,opt,name=lowest_52_week_date,json=lowest52WeekDate,proto3" json:"lowest_52_week_date,omitempty"`
	Timestamp           int64   `protobuf:"varint,26,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// contains filtered or unexported fields
}

func (*MonitoringResponse) Descriptor deprecated

func (*MonitoringResponse) Descriptor() ([]byte, []int)

Deprecated: Use MonitoringResponse.ProtoReflect.Descriptor instead.

func (*MonitoringResponse) GetAccTradePrice

func (x *MonitoringResponse) GetAccTradePrice() float64

func (*MonitoringResponse) GetAccTradePrice_24H

func (x *MonitoringResponse) GetAccTradePrice_24H() float64

func (*MonitoringResponse) GetAccTradeVolume

func (x *MonitoringResponse) GetAccTradeVolume() float64

func (*MonitoringResponse) GetAccTradeVolume_24H

func (x *MonitoringResponse) GetAccTradeVolume_24H() float64

func (*MonitoringResponse) GetChange

func (x *MonitoringResponse) GetChange() string

func (*MonitoringResponse) GetChangePrice

func (x *MonitoringResponse) GetChangePrice() int64

func (*MonitoringResponse) GetChangeRate

func (x *MonitoringResponse) GetChangeRate() float64

func (*MonitoringResponse) GetHighPrice

func (x *MonitoringResponse) GetHighPrice() int64

func (*MonitoringResponse) GetHighest_52WeekDate

func (x *MonitoringResponse) GetHighest_52WeekDate() string

func (*MonitoringResponse) GetHighest_52WeekPrice

func (x *MonitoringResponse) GetHighest_52WeekPrice() int64

func (*MonitoringResponse) GetLowPrice

func (x *MonitoringResponse) GetLowPrice() int64

func (*MonitoringResponse) GetLowest_52WeekDate

func (x *MonitoringResponse) GetLowest_52WeekDate() string

func (*MonitoringResponse) GetLowest_52WeekPrice

func (x *MonitoringResponse) GetLowest_52WeekPrice() int64

func (*MonitoringResponse) GetMarket

func (x *MonitoringResponse) GetMarket() string

func (*MonitoringResponse) GetOpeningPrice

func (x *MonitoringResponse) GetOpeningPrice() int64

func (*MonitoringResponse) GetPrevClosingPrice

func (x *MonitoringResponse) GetPrevClosingPrice() int64

func (*MonitoringResponse) GetSignedChangePrice

func (x *MonitoringResponse) GetSignedChangePrice() int64

func (*MonitoringResponse) GetSignedChangeRate

func (x *MonitoringResponse) GetSignedChangeRate() float64

func (*MonitoringResponse) GetTimestamp

func (x *MonitoringResponse) GetTimestamp() int64

func (*MonitoringResponse) GetTradeDate

func (x *MonitoringResponse) GetTradeDate() string

func (*MonitoringResponse) GetTradeDateKst

func (x *MonitoringResponse) GetTradeDateKst() string

func (*MonitoringResponse) GetTradePrice

func (x *MonitoringResponse) GetTradePrice() int64

func (*MonitoringResponse) GetTradeTime

func (x *MonitoringResponse) GetTradeTime() string

func (*MonitoringResponse) GetTradeTimeKst

func (x *MonitoringResponse) GetTradeTimeKst() string

func (*MonitoringResponse) GetTradeTimestamp

func (x *MonitoringResponse) GetTradeTimestamp() int64

func (*MonitoringResponse) GetTradeVolume

func (x *MonitoringResponse) GetTradeVolume() float64

func (*MonitoringResponse) ProtoMessage

func (*MonitoringResponse) ProtoMessage()

func (*MonitoringResponse) ProtoReflect

func (x *MonitoringResponse) ProtoReflect() protoreflect.Message

func (*MonitoringResponse) Reset

func (x *MonitoringResponse) Reset()

func (*MonitoringResponse) String

func (x *MonitoringResponse) String() string

type Monitoring_ServiceClient

type Monitoring_ServiceClient interface {
	SayHello(ctx context.Context, in *MonitoringRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[MonitoringResponse], error)
}

Monitoring_ServiceClient is the client API for Monitoring_Service service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type Monitoring_ServiceServer

type Monitoring_ServiceServer interface {
	SayHello(*MonitoringRequest, grpc.ServerStreamingServer[MonitoringResponse]) error
	// contains filtered or unexported methods
}

Monitoring_ServiceServer is the server API for Monitoring_Service service. All implementations must embed UnimplementedMonitoring_ServiceServer for forward compatibility.

type Monitoring_Service_SayHelloClient

type Monitoring_Service_SayHelloClient = grpc.ServerStreamingClient[MonitoringResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Monitoring_Service_SayHelloServer

type Monitoring_Service_SayHelloServer = grpc.ServerStreamingServer[MonitoringResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedMonitoring_ServiceServer

type UnimplementedMonitoring_ServiceServer struct{}

UnimplementedMonitoring_ServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

type UnsafeMonitoring_ServiceServer

type UnsafeMonitoring_ServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeMonitoring_ServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to Monitoring_ServiceServer will result in compilation errors.

Jump to